@@ -273,20 +273,42 @@ snapd_client_get_system_information_sync (SnapdClient *client,
  * Returns: (transfer full): a #SnapdSnap or %NULL on error.
  *
  * Since: 1.0
+ * Deprecated: 1.42: Use snapd_client_get_snap_sync()
  */
 SnapdSnap *
 snapd_client_list_one_sync (SnapdClient *client,
                             const gchar *name,
                             GCancellable *cancellable, GError **error)
+{
+    return snapd_client_get_snap_sync (client, name, cancellable, error);
+}
+
+/**
+ * snapd_client_get_snap_sync:
+ * @client: a #SnapdClient.
+ * @name: name of snap to get.
+ * @cancellable: (allow-none): a #GCancellable or %NULL.
+ * @error: (allow-none): #GError location to store the error occurring, or %NULL to ignore.
+ *
+ * Get information of a single installed snap. If the snap does not exist an error occurs.
+ *
+ * Returns: (transfer full): a #SnapdSnap or %NULL on error.
+ *
+ * Since: 1.42
+ */
+SnapdSnap *
+snapd_client_get_snap_sync (SnapdClient *client,
+                            const gchar *name,
+                            GCancellable *cancellable, GError **error)
 {
     g_auto(SyncData) data = { 0 };
 
     g_return_val_if_fail (SNAPD_IS_CLIENT (client), NULL);
 
     start_sync (&data);
-    snapd_client_list_one_async (client, name, cancellable, sync_cb, &data);
+    snapd_client_get_snap_async (client, name, cancellable, sync_cb, &data);
     end_sync (&data);
-    return snapd_client_list_one_finish (client, data.result, error);
+    return snapd_client_get_snap_finish (client, data.result, error);
 }
 
 /**
@@ -356,6 +378,7 @@ snapd_client_get_icon_sync (SnapdClient *client,
  * Returns: (transfer container) (element-type SnapdSnap): an array of #SnapdSnap or %NULL on error.
  *
  * Since: 1.0
+ * Deprecated: 1.42: Use snapd_client_get_snaps_sync()
  */
 GPtrArray *
 snapd_client_list_sync (SnapdClient *client,
@@ -366,9 +389,48 @@ snapd_client_list_sync (SnapdClient *client,
     g_return_val_if_fail (SNAPD_IS_CLIENT (client), NULL);
 
     start_sync (&data);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     snapd_client_list_async (client, cancellable, sync_cb, &data);
+G_GNUC_END_IGNORE_DEPRECATIONS
     end_sync (&data);
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     return snapd_client_list_finish (client, data.result, error);
+G_GNUC_END_IGNORE_DEPRECATIONS
+}
+
+/**
+ * snapd_client_get_snaps_sync:
+ * @client: a #SnapdClient.
+ * @flags: a set of #SnapdGetSnapsFlags to control what results are returned.
+ * @names: (allow-none): A list of snap names or %NULL.
+ * @cancellable: (allow-none): a #GCancellable or %NULL.
+ * @error: (allow-none): #GError location to store the error occurring, or %NULL to ignore.
+ *
+ * Get information on installed snaps (snaps with status %SNAPD_SNAP_STATUS_ACTIVE).
+ * If @flags contains %SNAPD_GET_SNAPS_FLAGS_INCLUDE_INACTIVE then also return snaps
+ * with status %SNAPD_SNAP_STATUS_INSTALLED.
+ *
+ * If @names is not %NULL and contains at least one name only snaps that match these names are
+ * returned. If a snap is not installed it is not returned (no error is generated).
+ *
+ * Returns: (transfer container) (element-type SnapdSnap): an array of #SnapdSnap or %NULL on error.
+ *
+ * Since: 1.42
+ */
+GPtrArray *
+snapd_client_get_snaps_sync (SnapdClient *client,
+                             SnapdGetSnapsFlags flags, gchar **names,
+                             GCancellable *cancellable, GError **error)
+{
+    g_auto(SyncData) data = { 0 };
+
+    g_return_val_if_fail (SNAPD_IS_CLIENT (client), NULL);
+
+    start_sync (&data);
+    snapd_client_get_snaps_async (client, flags, names, cancellable, sync_cb, &data);
+    end_sync (&data);
+    return snapd_client_get_snaps_finish (client, data.result, error);
 }
 
 /**
