@@ -60,6 +60,21 @@ typedef enum
     SNAPD_CHANGE_FILTER_READY
 } SnapdChangeFilter;
 
+/**
+ * SnapdGetSnapsFlags:
+ * @SNAPD_GET_SNAPS_FLAGS_NONE: No flags, default behaviour.
+ * @SNAPD_GET_SNAPS_FLAGS_INCLUDE_INACTIVE: Return snaps that are installed but not active.
+ *
+ * Flag to change which snaps are returned.
+ *
+ * Since: 1.42
+ */
+typedef enum
+{
+    SNAPD_GET_SNAPS_FLAGS_NONE              = 0,
+    SNAPD_GET_SNAPS_FLAGS_INCLUDE_INACTIVE = 1 << 0
+} SnapdGetSnapsFlags;
+
 /**
  * SnapdGetAppsFlags:
  * @SNAPD_GET_APPS_FLAGS_NONE: No flags, default behaviour.
@@ -72,16 +87,17 @@ typedef enum
 typedef enum
 {
     SNAPD_GET_APPS_FLAGS_NONE            = 0,
-    SNAPD_GET_APPS_FLAGS_SELECT_SERVICES = 1 << 0,
+    SNAPD_GET_APPS_FLAGS_SELECT_SERVICES = 1 << 0
 } SnapdGetAppsFlags;
 
 /**
  * SnapdFindFlags:
- * @SNAPD_FIND_FLAGS_NONE: No flags, default behaviour
+ * @SNAPD_FIND_FLAGS_NONE: No flags, default behaviour.
  * @SNAPD_FIND_FLAGS_MATCH_NAME: Search for snaps whose name matches the given
  *     string. The match is exact unless the string ends in *.
- * @SNAPD_FIND_FLAGS_SELECT_PRIVATE: Search private snaps
- * @SNAPD_FIND_FLAGS_SELECT_REFRESH: Deprecated, do not use
+ * @SNAPD_FIND_FLAGS_SELECT_PRIVATE: Search private snaps.
+ * @SNAPD_FIND_FLAGS_SELECT_REFRESH: Deprecated, do not use.
+ * @SNAPD_FIND_FLAGS_SCOPE_WIDE: Search for snaps from any architecture or branch.
  *
  * Flag to change how a find is performed.
  *
@@ -92,7 +108,8 @@ typedef enum
     SNAPD_FIND_FLAGS_NONE            = 0,
     SNAPD_FIND_FLAGS_MATCH_NAME      = 1 << 0,
     SNAPD_FIND_FLAGS_SELECT_PRIVATE  = 1 << 1,
-    SNAPD_FIND_FLAGS_SELECT_REFRESH  = 1 << 2
+    SNAPD_FIND_FLAGS_SELECT_REFRESH  = 1 << 2,
+    SNAPD_FIND_FLAGS_SCOPE_WIDE      = 1 << 3
 } SnapdFindFlags;
 
 /**
@@ -285,25 +302,53 @@ SnapdSystemInformation *snapd_client_get_system_information_finish (SnapdClient
 
 GPtrArray              *snapd_client_list_sync                     (SnapdClient          *client,
                                                                     GCancellable         *cancellable,
-                                                                    GError              **error);
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_get_snaps_sync);
 void                    snapd_client_list_async                    (SnapdClient          *client,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
-                                                                    gpointer              user_data);
+                                                                    gpointer              user_data) G_DEPRECATED_FOR(snapd_client_get_snaps_async);
 GPtrArray              *snapd_client_list_finish                   (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_get_snaps_finish);
+
+GPtrArray              *snapd_client_get_snaps_sync                (SnapdClient          *client,
+                                                                    SnapdGetSnapsFlags    flags,
+                                                                    gchar               **names,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_get_snaps_async               (SnapdClient          *client,
+                                                                    SnapdGetSnapsFlags    flags,
+                                                                    gchar               **names,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+GPtrArray              *snapd_client_get_snaps_finish              (SnapdClient          *client,
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
 SnapdSnap              *snapd_client_list_one_sync                 (SnapdClient          *client,
                                                                     const gchar          *name,
                                                                     GCancellable         *cancellable,
-                                                                    GError              **error);
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_get_snap_sync);
 void                    snapd_client_list_one_async                (SnapdClient          *client,
                                                                     const gchar          *name,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
-                                                                    gpointer              user_data);
+                                                                    gpointer              user_data) G_DEPRECATED_FOR(snapd_client_get_snap_async);
 SnapdSnap              *snapd_client_list_one_finish               (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_get_snap_finish);
+
+SnapdSnap              *snapd_client_get_snap_sync                 (SnapdClient          *client,
+                                                                    const gchar          *name,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_get_snap_async                (SnapdClient          *client,
+                                                                    const gchar          *name,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+SnapdSnap              *snapd_client_get_snap_finish               (SnapdClient          *client,
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
