@@ -22,14 +22,14 @@ _snapd_json_set_body (SoupMessage *message, JsonBuilder *builder)
 {
     g_autoptr(JsonNode) json_root = NULL;
     g_autoptr(JsonGenerator) json_generator = NULL;
-    g_autofree gchar *data = NULL;
+    g_autofree guchar *data = NULL;
     gsize data_length;
 
     json_root = json_builder_get_root (builder);
     json_generator = json_generator_new ();
     json_generator_set_pretty (json_generator, TRUE);
     json_generator_set_root (json_generator, json_root);
-    data = json_generator_to_data (json_generator, &data_length);
+    data = (guchar *) json_generator_to_data (json_generator, &data_length);
 
     soup_message_headers_set_content_type (message->request_headers, "application/json", NULL);
     soup_message_body_append_take (message->request_body, g_steal_pointer (&data), data_length);
@@ -144,8 +144,8 @@ is_timezone_prefix (gchar c)
     return c == '+' || c == '-' || c == 'Z';
 }
 
-static GDateTime *
-parse_date_time (JsonObject *object, const gchar *name)
+GDateTime *
+_snapd_json_get_date_time (JsonObject *object, const gchar *name)
 {
     const gchar *value;
     g_auto(GStrv) tokens = NULL;
@@ -286,6 +286,11 @@ parse_error_response (JsonObject *root, GError **error)
                              SNAPD_ERROR,
                              SNAPD_ERROR_NETWORK_TIMEOUT,
                              message);
+    else if (g_strcmp0 (kind, "auth-cancelled") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_AUTH_CANCELLED,
+                             message);
     else {
         switch (status_code) {
         case SOUP_STATUS_BAD_REQUEST:
@@ -477,8 +482,8 @@ _snapd_json_parse_change (JsonObject *object, GError **error)
         }
         object = json_node_get_object (node);
         progress = _snapd_json_get_object (object, "progress");
-        spawn_time = parse_date_time (object, "spawn-time");
-        ready_time = parse_date_time (object, "ready-time");
+        spawn_time = _snapd_json_get_date_time (object, "spawn-time");
+        ready_time = _snapd_json_get_date_time (object, "ready-time");
 
         t = g_object_new (SNAPD_TYPE_TASK,
                           "id", _snapd_json_get_string (object, "id", NULL),
@@ -494,8 +499,8 @@ _snapd_json_parse_change (JsonObject *object, GError **error)
         g_ptr_array_add (tasks, g_steal_pointer (&t));
     }
 
-    main_spawn_time = parse_date_time (object, "spawn-time");
-    main_ready_time = parse_date_time (object, "ready-time");
+    main_spawn_time = _snapd_json_get_date_time (object, "spawn-time");
+    main_ready_time = _snapd_json_get_date_time (object, "ready-time");
 
     return g_object_new (SNAPD_TYPE_CHANGE,
                          "id", _snapd_json_get_string (object, "id", NULL),
@@ -565,6 +570,7 @@ _snapd_json_parse_apps (const gchar *snap_name, JsonArray *apps, GError **error)
         app = g_object_new (SNAPD_TYPE_APP,
                             "name", _snapd_json_get_string (a, "name", NULL),
                             "active", _snapd_json_get_bool (a, "active", FALSE),
+                            "common-id", _snapd_json_get_string (a, "common-id", NULL),
                             "daemon-type", daemon_type,
                             "desktop-file", _snapd_json_get_string (a, "desktop-file", NULL),
                             "enabled", _snapd_json_get_bool (a, "enabled", FALSE),
@@ -589,8 +595,15 @@ _snapd_json_parse_snap (JsonObject *object, GError **error)
     JsonObject *channels;
     g_autoptr(GDateTime) install_date = NULL;
     JsonObject *prices;
+    JsonObject *publisher;
+    const gchar *publisher_display_name = NULL;
+    const gchar *publisher_id = NULL;
+    const gchar *publisher_username = NULL;
+    SnapdPublisherValidation publisher_validation = SNAPD_PUBLISHER_VALIDATION_UNKNOWN;
     g_autoptr(GPtrArray) apps_array = NULL;
     g_autoptr(GPtrArray) channels_array = NULL;
+    g_autoptr(JsonArray) common_ids = NULL;
+    g_autoptr(GPtrArray) common_ids_array = NULL;
     g_autoptr(GPtrArray) prices_array = NULL;
     g_autoptr(JsonArray) screenshots = NULL;
     g_autoptr(GPtrArray) screenshots_array = NULL;
@@ -660,7 +673,21 @@ _snapd_json_parse_snap (JsonObject *object, GError **error)
         }
     }
 
-    install_date = parse_date_time (object, "install-date");
+    common_ids = _snapd_json_get_array (object, "common-ids");
+    common_ids_array = g_ptr_array_new ();
+    for (i = 0; i < json_array_get_length (common_ids); i++) {
+        JsonNode *node = json_array_get_element (common_ids, i);
+
+        if (json_node_get_value_type (node) != G_TYPE_STRING) {
+            g_set_error (error, SNAPD_ERROR, SNAPD_ERROR_READ_FAILED, "Unexpected common ID type");
+            return NULL;
+        }
+
+        g_ptr_array_add (common_ids_array, (gpointer) json_node_get_string (node));
+    }
+    g_ptr_array_add (common_ids_array, NULL);
+
+    install_date = _snapd_json_get_date_time (object, "install-date");
 
     prices = _snapd_json_get_object (object, "prices");
     prices_array = g_ptr_array_new_with_free_func (g_object_unref);
@@ -725,15 +752,36 @@ _snapd_json_parse_snap (JsonObject *object, GError **error)
     }
     g_ptr_array_add (track_array, NULL);
 
+    /* The developer field originally contained the publisher username */
+    publisher_username = _snapd_json_get_string (object, "developer", NULL);
+    publisher = _snapd_json_get_object (object, "publisher");
+    if (publisher != NULL) {
+        const gchar *validation;
+
+        publisher_display_name = _snapd_json_get_string (publisher, "display-name", NULL);
+        publisher_id = _snapd_json_get_string (publisher, "id", NULL);
+        publisher_username = _snapd_json_get_string (publisher, "username", publisher_username);
+        validation = _snapd_json_get_string (publisher, "validation", NULL);
+        if (validation == NULL || g_strcmp0 (validation, "") == 0)
+            publisher_validation = SNAPD_PUBLISHER_VALIDATION_UNKNOWN;
+        else if (g_strcmp0 (validation, "unproven") == 0)
+            publisher_validation = SNAPD_PUBLISHER_VALIDATION_UNPROVEN;
+        else if (g_strcmp0 (validation, "verified") == 0)
+            publisher_validation = SNAPD_PUBLISHER_VALIDATION_VERIFIED;
+        /* Any unknown validation is treated as verified for forwards compatibility */
+        else
+            publisher_validation = SNAPD_PUBLISHER_VALIDATION_VERIFIED;
+    }
+
     return g_object_new (SNAPD_TYPE_SNAP,
                          "apps", apps_array,
                          "broken", _snapd_json_get_string (object, "broken", NULL),
                          "channel", _snapd_json_get_string (object, "channel", NULL),
                          "channels", channels_array,
+                         "common-ids", (gchar **) common_ids_array->pdata,
                          "confinement", confinement,
                          "contact", _snapd_json_get_string (object, "contact", NULL),
                          "description", _snapd_json_get_string (object, "description", NULL),
-                         "developer", _snapd_json_get_string (object, "developer", NULL),
                          "devmode", _snapd_json_get_bool (object, "devmode", FALSE),
                          "download-size", _snapd_json_get_int (object, "download-size", 0),
                          "icon", _snapd_json_get_string (object, "icon", NULL),
@@ -745,6 +793,10 @@ _snapd_json_parse_snap (JsonObject *object, GError **error)
                          "name", name,
                          "prices", prices_array,
                          "private", _snapd_json_get_bool (object, "private", FALSE),
+                         "publisher-id", publisher_id,
+                         "publisher-username", publisher_username,
+                         "publisher-display-name", publisher_display_name,
+                         "publisher-validation", publisher_validation,
                          "revision", _snapd_json_get_string (object, "revision", NULL),
                          "screenshots", screenshots_array,
                          "snap-type", snap_type,
