@@ -38,10 +38,10 @@ struct _SnapdSnap
     gchar *broken;
     gchar *channel;
     GPtrArray *channels;
+    gchar **common_ids;
     SnapdConfinement confinement;
     gchar *contact;
     gchar *description;
-    gchar *developer;
     gboolean devmode;
     gint64 download_size;
     gchar *icon;
@@ -53,6 +53,10 @@ struct _SnapdSnap
     gchar *name;
     GPtrArray *prices;
     gboolean private;
+    gchar *publisher_display_name;
+    gchar *publisher_id;
+    gchar *publisher_username;
+    SnapdPublisherValidation publisher_validation;
     gchar *revision;
     GPtrArray *screenshots;
     SnapdSnapStatus status;
@@ -96,6 +100,11 @@ enum
     PROP_CHANNELS,
     PROP_TRACKS,
     PROP_BROKEN,
+    PROP_COMMON_IDS,
+    PROP_PUBLISHER_DISPLAY_NAME,
+    PROP_PUBLISHER_ID,
+    PROP_PUBLISHER_USERNAME,
+    PROP_PUBLISHER_VALIDATION,
     PROP_LAST
 };
 
@@ -234,6 +243,23 @@ snapd_snap_match_channel (SnapdSnap *snap, const gchar *name)
     return matched_channel;
 }
 
+/**
+ * snapd_snap_get_common_ids:
+ * @snap: a #SnapdSnap.
+ *
+ * Get common IDs associated with this snap.
+ *
+ * Returns: (transfer none) (array zero-terminated=1): an array of common ids.
+ *
+ * Since: 1.41
+ */
+gchar **
+snapd_snap_get_common_ids (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
+    return snap->common_ids;
+}
+
 /**
  * snapd_snap_get_confinement:
  * @snap: a #SnapdSnap.
@@ -294,12 +320,13 @@ snapd_snap_get_description (SnapdSnap *snap)
  * Returns: a developer name.
  *
  * Since: 1.0
+ * Deprecated: 1.42: Use snapd_snap_get_publisher_username()
  */
 const gchar *
 snapd_snap_get_developer (SnapdSnap *snap)
 {
     g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
-    return snap->developer;
+    return snap->publisher_username;
 }
 
 /**
@@ -508,6 +535,74 @@ snapd_snap_get_private (SnapdSnap *snap)
     return snap->private;
 }
 
+/**
+ * snapd_snap_get_publisher_display_name:
+ * @snap: a #SnapdSnap.
+ *
+ * Get the display name of the publisher who created this snap.
+ *
+ * Returns: a publisher display name.
+ *
+ * Since: 1.42
+ */
+const gchar *
+snapd_snap_get_publisher_display_name (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
+    return snap->publisher_display_name;
+}
+
+/**
+ * snapd_snap_get_publisher_id:
+ * @snap: a #SnapdSnap.
+ *
+ * Get the ID of the publisher who created this snap.
+ *
+ * Returns: a publisher ID.
+ *
+ * Since: 1.42
+ */
+const gchar *
+snapd_snap_get_publisher_id (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
+    return snap->publisher_id;
+}
+
+/**
+ * snapd_snap_get_publisher_username:
+ * @snap: a #SnapdSnap.
+ *
+ * Get the username of the publisher who created this snap.
+ *
+ * Returns: a publisher username.
+ *
+ * Since: 1.42
+ */
+const gchar *
+snapd_snap_get_publisher_username (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
+    return snap->publisher_username;
+}
+
+/**
+ * snapd_snap_get_publisher_validation:
+ * @snap: a #SnapdSnap.
+ *
+ * Get the validation for the snap publisher, e.g. %SNAPD_PUBLISHER_VALIDATION_VERIFIED
+ *
+ * Returns: a #SnapdPublisherValidation.
+ *
+ * Since: 1.42
+ */
+SnapdPublisherValidation
+snapd_snap_get_publisher_validation (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), SNAPD_PUBLISHER_VALIDATION_UNKNOWN);
+    return snap->publisher_validation;
+}
+
 /**
  * snapd_snap_get_revision:
  * @snap: a #SnapdSnap.
@@ -699,10 +794,6 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
         g_free (snap->description);
         snap->description = g_strdup (g_value_get_string (value));
         break;
-    case PROP_DEVELOPER:
-        g_free (snap->developer);
-        snap->developer = g_strdup (g_value_get_string (value));
-        break;
     case PROP_DEVMODE:
         snap->devmode = g_value_get_boolean (value);
         break;
@@ -744,6 +835,22 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
     case PROP_PRIVATE:
         snap->private = g_value_get_boolean (value);
         break;
+    case PROP_PUBLISHER_DISPLAY_NAME:
+        g_free (snap->publisher_display_name);
+        snap->publisher_display_name = g_strdup (g_value_get_string (value));
+        break;
+    case PROP_PUBLISHER_ID:
+        g_free (snap->publisher_id);
+        snap->publisher_id = g_strdup (g_value_get_string (value));
+        break;
+    case PROP_PUBLISHER_USERNAME:
+    case PROP_DEVELOPER:
+        g_free (snap->publisher_username);
+        snap->publisher_username = g_strdup (g_value_get_string (value));
+        break;
+    case PROP_PUBLISHER_VALIDATION:
+        snap->publisher_validation = g_value_get_enum (value);
+        break;
     case PROP_REVISION:
         g_free (snap->revision);
         snap->revision = g_strdup (g_value_get_string (value));
@@ -782,6 +889,10 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
         g_free (snap->license);
         snap->license = g_strdup (g_value_get_string (value));
         break;
+    case PROP_COMMON_IDS:
+        g_strfreev (snap->common_ids);
+        snap->common_ids = g_strdupv (g_value_get_boxed (value));
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -815,9 +926,6 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_DESCRIPTION:
         g_value_set_string (value, snap->description);
         break;
-    case PROP_DEVELOPER:
-        g_value_set_string (value, snap->developer);
-        break;
     case PROP_DEVMODE:
         g_value_set_boolean (value, snap->devmode);
         break;
@@ -851,6 +959,19 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_PRIVATE:
         g_value_set_boolean (value, snap->private);
         break;
+    case PROP_PUBLISHER_DISPLAY_NAME:
+        g_value_set_string (value, snap->publisher_display_name);
+        break;
+    case PROP_PUBLISHER_ID:
+        g_value_set_string (value, snap->publisher_id);
+        break;
+    case PROP_PUBLISHER_USERNAME:
+    case PROP_DEVELOPER:
+        g_value_set_string (value, snap->publisher_username);
+        break;
+    case PROP_PUBLISHER_VALIDATION:
+        g_value_set_enum (value, snap->publisher_validation);
+        break;
     case PROP_REVISION:
         g_value_set_string (value, snap->revision);
         break;
@@ -881,6 +1002,9 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_LICENSE:
         g_value_set_string (value, snap->license);
         break;
+    case PROP_COMMON_IDS:
+        g_value_set_boxed (value, snap->common_ids);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -896,15 +1020,18 @@ snapd_snap_finalize (GObject *object)
     g_clear_pointer (&snap->broken, g_free);
     g_clear_pointer (&snap->channel, g_free);
     g_clear_pointer (&snap->channels, g_ptr_array_unref);
+    g_clear_pointer (&snap->common_ids, g_strfreev);
     g_clear_pointer (&snap->contact, g_free);
     g_clear_pointer (&snap->description, g_free);
-    g_clear_pointer (&snap->developer, g_free);
     g_clear_pointer (&snap->icon, g_free);
     g_clear_pointer (&snap->id, g_free);
     g_clear_pointer (&snap->install_date, g_date_time_unref);
     g_clear_pointer (&snap->name, g_free);
     g_clear_pointer (&snap->license, g_free);
     g_clear_pointer (&snap->prices, g_ptr_array_unref);
+    g_clear_pointer (&snap->publisher_display_name, g_free);
+    g_clear_pointer (&snap->publisher_id, g_free);
+    g_clear_pointer (&snap->publisher_username, g_free);
     g_clear_pointer (&snap->revision, g_free);
     g_clear_pointer (&snap->screenshots, g_ptr_array_unref);
     g_clear_pointer (&snap->summary, g_free);
@@ -953,6 +1080,13 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                          "Channels this snap is available on",
                                                          G_TYPE_PTR_ARRAY,
                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_COMMON_IDS,
+                                     g_param_spec_boxed ("common-ids",
+                                                         "common-ids",
+                                                         "Common IDs",
+                                                         G_TYPE_STRV,
+                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_CONFINEMENT,
                                      g_param_spec_enum ("confinement",
@@ -980,7 +1114,7 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                           "developer",
                                                           "Developer who created the snap",
                                                           NULL,
-                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_DEPRECATED));
     g_object_class_install_property (gobject_class,
                                      PROP_DEVMODE,
                                      g_param_spec_boolean ("devmode",
@@ -1065,6 +1199,34 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                            "TRUE if this snap is only available to its author",
                                                            FALSE,
                                                            G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_PUBLISHER_DISPLAY_NAME,
+                                     g_param_spec_string ("publisher-display-name",
+                                                          "publisher-display-name",
+                                                          "Display name for snap publisher",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_PUBLISHER_ID,
+                                     g_param_spec_string ("publisher-id",
+                                                          "publisher-id",
+                                                          "ID for snap publisher",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_PUBLISHER_USERNAME,
+                                     g_param_spec_string ("publisher-username",
+                                                          "publisher-username",
+                                                          "Username for snap publisher",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_PUBLISHER_VALIDATION,
+                                     g_param_spec_enum ("publisher-validation",
+                                                        "publisher-validation",
+                                                        "Validation for snap publisher",
+                                                        SNAPD_TYPE_PUBLISHER_VALIDATION, SNAPD_PUBLISHER_VALIDATION_UNKNOWN,
+                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_REVISION,
                                      g_param_spec_string ("revision",
