@@ -157,6 +157,26 @@ private:
     Q_DECLARE_PRIVATE(QSnapdListRequest)
 };
 
+class QSnapdGetSnapsRequestPrivate;
+class Q_DECL_EXPORT QSnapdGetSnapsRequest : public QSnapdRequest
+{
+    Q_OBJECT
+    Q_PROPERTY(int snapCount READ snapCount)
+
+public:
+    explicit QSnapdGetSnapsRequest (int flags, const QStringList& snaps, void *snapd_client, QObject *parent = 0);
+    ~QSnapdGetSnapsRequest ();
+    virtual void runSync ();
+    virtual void runAsync ();
+    Q_INVOKABLE int snapCount () const;
+    Q_INVOKABLE QSnapdSnap *snap (int) const;
+    void handleResult (void *, void *);
+
+private:
+    QSnapdGetSnapsRequestPrivate *d_ptr;
+    Q_DECLARE_PRIVATE(QSnapdGetSnapsRequest)
+};
+
 class QSnapdListOneRequestPrivate;
 class Q_DECL_EXPORT QSnapdListOneRequest : public QSnapdRequest
 {
@@ -175,6 +195,24 @@ private:
     Q_DECLARE_PRIVATE(QSnapdListOneRequest)
 };
 
+class QSnapdGetSnapRequestPrivate;
+class Q_DECL_EXPORT QSnapdGetSnapRequest : public QSnapdRequest
+{
+    Q_OBJECT
+
+public:
+    explicit QSnapdGetSnapRequest (const QString& name, void *snapd_client, QObject *parent = 0);
+    ~QSnapdGetSnapRequest ();
+    virtual void runSync ();
+    virtual void runAsync ();
+    Q_INVOKABLE QSnapdSnap *snap () const;
+    void handleResult (void *, void *);
+
+private:
+    QSnapdGetSnapRequestPrivate *d_ptr;
+    Q_DECLARE_PRIVATE(QSnapdGetSnapRequest)
+};
+
 class QSnapdGetAppsRequestPrivate;
 class Q_DECL_EXPORT QSnapdGetAppsRequest : public QSnapdRequest
 {
@@ -759,6 +797,11 @@ public:
         FilterReady
     };
     Q_ENUM(ChangeFilter)
+    enum GetSnapsFlag
+    {
+        IncludeInactive = 1 << 0
+    };
+    Q_DECLARE_FLAGS(GetSnapsFlags, GetSnapsFlag);
     enum GetAppsFlag
     {
         SelectServices = 1 << 0
@@ -768,7 +811,8 @@ public:
     {
         None          = 0,
         MatchName     = 1 << 0,
-        SelectPrivate = 1 << 1
+        SelectPrivate = 1 << 1,
+        ScopeWide     = 1 << 2
     };
     Q_DECLARE_FLAGS(FindFlags, FindFlag);
     enum InstallFlag
@@ -806,8 +850,14 @@ public:
     Q_INVOKABLE QSnapdGetChangeRequest *getChange (const QString &id);
     Q_INVOKABLE QSnapdAbortChangeRequest *abortChange (const QString &id);
     Q_INVOKABLE QSnapdGetSystemInformationRequest *getSystemInformation ();
-    Q_INVOKABLE QSnapdListRequest *list ();
-    Q_INVOKABLE QSnapdListOneRequest *listOne (const QString &name);
+    Q_INVOKABLE Q_DECL_DEPRECATED_X("Use getSnaps()") QSnapdListRequest *list ();
+    Q_INVOKABLE QSnapdGetSnapsRequest *getSnaps (GetSnapsFlags flags, const QStringList &snaps);
+    Q_INVOKABLE QSnapdGetSnapsRequest *getSnaps (GetSnapsFlags flags, const QString &snap);
+    Q_INVOKABLE QSnapdGetSnapsRequest *getSnaps (const QStringList &snaps);
+    Q_INVOKABLE QSnapdGetSnapsRequest *getSnaps (const QString &snap);
+    Q_INVOKABLE QSnapdGetSnapsRequest *getSnaps ();
+    Q_INVOKABLE Q_DECL_DEPRECATED_X("Use getSnap()") QSnapdListOneRequest *listOne (const QString &name);
+    Q_INVOKABLE QSnapdGetSnapRequest *getSnap (const QString &name);
     Q_INVOKABLE QSnapdGetAppsRequest *getApps ();
     Q_INVOKABLE QSnapdGetAppsRequest *getApps (GetAppsFlags flags);
     Q_INVOKABLE QSnapdGetIconRequest *getIcon (const QString &name);
