@@ -105,6 +105,21 @@ public:
     GPtrArray *snaps = NULL;
 };
 
+class QSnapdGetSnapsRequestPrivate
+{
+public:
+    QSnapdGetSnapsRequestPrivate (int flags, const QStringList& snaps) :
+        flags(flags), filter_snaps(snaps) {}
+    ~QSnapdGetSnapsRequestPrivate ()
+    {
+        if (snaps != NULL)
+            g_ptr_array_unref (snaps);
+    }
+    int flags;
+    QStringList filter_snaps;
+    GPtrArray *snaps = NULL;
+};
+
 class QSnapdListOneRequestPrivate
 {
 public:
@@ -119,6 +134,20 @@ public:
     SnapdSnap *snap = NULL;
 };
 
+class QSnapdGetSnapRequestPrivate
+{
+public:
+    QSnapdGetSnapRequestPrivate (const QString& name) :
+        name(name) {}
+    ~QSnapdGetSnapRequestPrivate ()
+    {
+        if (snap != NULL)
+            g_object_unref (snap);
+    }
+    QString name;
+    SnapdSnap *snap = NULL;
+};
+
 class QSnapdGetAppsRequestPrivate
 {
 public:
