@@ -208,6 +208,37 @@ QSnapdListRequest *QSnapdClient::list ()
     return new QSnapdListRequest (d->client);
 }
 
+QSnapdGetSnapsRequest::~QSnapdGetSnapsRequest ()
+{
+    delete d_ptr;
+}
+
+QSnapdGetSnapsRequest *QSnapdClient::getSnaps (GetSnapsFlags flags, const QStringList &snaps)
+{
+    Q_D(QSnapdClient);
+    return new QSnapdGetSnapsRequest (flags, snaps, d->client);
+}
+
+QSnapdGetSnapsRequest *QSnapdClient::getSnaps (GetSnapsFlags flags, const QString &snap)
+{
+    return getSnaps (flags, QStringList(snap));
+}
+
+QSnapdGetSnapsRequest *QSnapdClient::getSnaps (const QStringList &snaps)
+{
+    return getSnaps (0, snaps);
+}
+
+QSnapdGetSnapsRequest *QSnapdClient::getSnaps (const QString &snap)
+{
+    return getSnaps (0, QStringList(snap));
+}
+
+QSnapdGetSnapsRequest *QSnapdClient::getSnaps ()
+{
+    return getSnaps (0, QStringList ());
+}
+
 QSnapdListOneRequest::~QSnapdListOneRequest ()
 {
     delete d_ptr;
@@ -219,6 +250,17 @@ QSnapdListOneRequest *QSnapdClient::listOne (const QString& name)
     return new QSnapdListOneRequest (name, d->client);
 }
 
+QSnapdGetSnapRequest::~QSnapdGetSnapRequest ()
+{
+    delete d_ptr;
+}
+
+QSnapdGetSnapRequest *QSnapdClient::getSnap (const QString& name)
+{
+    Q_D(QSnapdClient);
+    return new QSnapdGetSnapRequest (name, d->client);
+}
+
 QSnapdGetAppsRequest::~QSnapdGetAppsRequest ()
 {
     delete d_ptr;
@@ -927,7 +969,7 @@ void QSnapdListRequest::runSync ()
 {
     Q_D(QSnapdListRequest);
     g_autoptr(GError) error = NULL;
-    d->snaps = snapd_client_list_sync (SNAPD_CLIENT (getClient ()), G_CANCELLABLE (getCancellable ()), &error);
+    d->snaps = snapd_client_get_snaps_sync (SNAPD_CLIENT (getClient ()), SNAPD_GET_SNAPS_FLAGS_NONE, NULL, G_CANCELLABLE (getCancellable ()), &error);
     finish (error);
 }
 
@@ -936,7 +978,7 @@ void QSnapdListRequest::handleResult (void *object, void *result)
     g_autoptr(GPtrArray) snaps = NULL;
     g_autoptr(GError) error = NULL;
 
-    snaps = snapd_client_list_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
+    snaps = snapd_client_get_snaps_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
 
     Q_D(QSnapdListRequest);
     d->snaps = (GPtrArray*) g_steal_pointer (&snaps);
@@ -951,7 +993,7 @@ static void list_ready_cb (GObject *object, GAsyncResult *result, gpointer data)
 
 void QSnapdListRequest::runAsync ()
 {
-    snapd_client_list_async (SNAPD_CLIENT (getClient ()), G_CANCELLABLE (getCancellable ()), list_ready_cb, (gpointer) this);
+    snapd_client_get_snaps_async (SNAPD_CLIENT (getClient ()), SNAPD_GET_SNAPS_FLAGS_NONE, NULL, G_CANCELLABLE (getCancellable ()), list_ready_cb, (gpointer) this);
 }
 
 int QSnapdListRequest::snapCount () const
@@ -968,6 +1010,87 @@ QSnapdSnap *QSnapdListRequest::snap (int n) const
     return new QSnapdSnap (d->snaps->pdata[n]);
 }
 
+static gchar **
+string_list_to_strv (const QStringList& list)
+{
+    gchar **value;
+    int size, i;
+
+    size = list.size ();
+    value = (gchar **) malloc (sizeof (gchar *) * (size + 1));
+    for (i = 0; i < size; i++)
+        value[i] = g_strdup (list[i].toStdString ().c_str ());
+    value[size] = NULL;
+
+    return value;
+}
+
+static SnapdGetSnapsFlags convertGetSnapsFlags (int flags)
+{
+    int result = SNAPD_GET_SNAPS_FLAGS_NONE;
+
+    if ((flags & QSnapdClient::GetSnapsFlag::IncludeInactive) != 0)
+        result |= SNAPD_GET_SNAPS_FLAGS_INCLUDE_INACTIVE;
+
+    return (SnapdGetSnapsFlags) result;
+}
+
+QSnapdGetSnapsRequest::QSnapdGetSnapsRequest (int flags, const QStringList& snaps, void *snapd_client, QObject *parent) :
+    QSnapdRequest (snapd_client, parent),
+    d_ptr (new QSnapdGetSnapsRequestPrivate (flags, snaps)) {}
+
+void QSnapdGetSnapsRequest::runSync ()
+{
+    Q_D(QSnapdGetSnapsRequest);
+    g_auto(GStrv) snaps = NULL;
+    g_autoptr(GError) error = NULL;
+
+    snaps = string_list_to_strv (d->filter_snaps);
+    d->snaps = snapd_client_get_snaps_sync (SNAPD_CLIENT (getClient ()), convertGetSnapsFlags (d->flags), snaps, G_CANCELLABLE (getCancellable ()), &error);
+    finish (error);
+}
+
+void QSnapdGetSnapsRequest::handleResult (void *object, void *result)
+{
+    g_autoptr(GPtrArray) snaps = NULL;
+    g_autoptr(GError) error = NULL;
+
+    snaps = snapd_client_get_snaps_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
+
+    Q_D(QSnapdGetSnapsRequest);
+    d->snaps = (GPtrArray*) g_steal_pointer (&snaps);
+    finish (error);
+}
+
+static void get_snaps_ready_cb (GObject *object, GAsyncResult *result, gpointer data)
+{
+    QSnapdGetSnapsRequest *request = static_cast<QSnapdGetSnapsRequest*>(data);
+    request->handleResult (object, result);
+}
+
+void QSnapdGetSnapsRequest::runAsync ()
+{
+    Q_D(QSnapdGetSnapsRequest);
+    g_auto(GStrv) snaps = NULL;
+
+    snaps = string_list_to_strv (d->filter_snaps);
+    snapd_client_get_snaps_async (SNAPD_CLIENT (getClient ()), convertGetSnapsFlags (d->flags), snaps, G_CANCELLABLE (getCancellable ()), get_snaps_ready_cb, (gpointer) this);
+}
+
+int QSnapdGetSnapsRequest::snapCount () const
+{
+    Q_D(const QSnapdGetSnapsRequest);
+    return d->snaps != NULL ? d->snaps->len : 0;
+}
+
+QSnapdSnap *QSnapdGetSnapsRequest::snap (int n) const
+{
+    Q_D(const QSnapdGetSnapsRequest);
+    if (d->snaps == NULL || n < 0 || (guint) n >= d->snaps->len)
+        return NULL;
+    return new QSnapdSnap (d->snaps->pdata[n]);
+}
+
 QSnapdListOneRequest::QSnapdListOneRequest (const QString& name, void *snapd_client, QObject *parent) :
     QSnapdRequest (snapd_client, parent),
     d_ptr (new QSnapdListOneRequestPrivate (name)) {}
@@ -976,7 +1099,7 @@ void QSnapdListOneRequest::runSync ()
 {
     Q_D(QSnapdListOneRequest);
     g_autoptr(GError) error = NULL;
-    d->snap = snapd_client_list_one_sync (SNAPD_CLIENT (getClient ()), d->name.isNull () ? NULL : d->name.toStdString ().c_str (), G_CANCELLABLE (getCancellable ()), &error);
+    d->snap = snapd_client_get_snap_sync (SNAPD_CLIENT (getClient ()), d->name.isNull () ? NULL : d->name.toStdString ().c_str (), G_CANCELLABLE (getCancellable ()), &error);
     finish (error);
 }
 
@@ -985,7 +1108,7 @@ void QSnapdListOneRequest::handleResult (void *object, void *result)
     g_autoptr(SnapdSnap) snap = NULL;
     g_autoptr(GError) error = NULL;
 
-    snap = snapd_client_list_one_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
+    snap = snapd_client_get_snap_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
 
     Q_D(QSnapdListOneRequest);
     d->snap = (SnapdSnap*) g_steal_pointer (&snap);
@@ -1001,7 +1124,7 @@ static void list_one_ready_cb (GObject *object, GAsyncResult *result, gpointer d
 void QSnapdListOneRequest::runAsync ()
 {
     Q_D(QSnapdListOneRequest);
-    snapd_client_list_one_async (SNAPD_CLIENT (getClient ()), d->name.isNull () ? NULL : d->name.toStdString ().c_str (), G_CANCELLABLE (getCancellable ()), list_one_ready_cb, (gpointer) this);
+    snapd_client_get_snap_async (SNAPD_CLIENT (getClient ()), d->name.isNull () ? NULL : d->name.toStdString ().c_str (), G_CANCELLABLE (getCancellable ()), list_one_ready_cb, (gpointer) this);
 }
 
 QSnapdSnap *QSnapdListOneRequest::snap () const
@@ -1010,6 +1133,48 @@ QSnapdSnap *QSnapdListOneRequest::snap () const
     return new QSnapdSnap (d->snap);
 }
 
+QSnapdGetSnapRequest::QSnapdGetSnapRequest (const QString& name, void *snapd_client, QObject *parent) :
+    QSnapdRequest (snapd_client, parent),
+    d_ptr (new QSnapdGetSnapRequestPrivate (name)) {}
+
+void QSnapdGetSnapRequest::runSync ()
+{
+    Q_D(QSnapdGetSnapRequest);
+    g_autoptr(GError) error = NULL;
+    d->snap = snapd_client_get_snap_sync (SNAPD_CLIENT (getClient ()), d->name.isNull () ? NULL : d->name.toStdString ().c_str (), G_CANCELLABLE (getCancellable ()), &error);
+    finish (error);
+}
+
+void QSnapdGetSnapRequest::handleResult (void *object, void *result)
+{
+    g_autoptr(SnapdSnap) snap = NULL;
+    g_autoptr(GError) error = NULL;
+
+    snap = snapd_client_get_snap_finish (SNAPD_CLIENT (object), G_ASYNC_RESULT (result), &error);
+
+    Q_D(QSnapdGetSnapRequest);
+    d->snap = (SnapdSnap*) g_steal_pointer (&snap);
+    finish (error);
+}
+
+static void get_snap_ready_cb (GObject *object, GAsyncResult *result, gpointer data)
+{
+    QSnapdGetSnapRequest *request = static_cast<QSnapdGetSnapRequest*>(data);
+    request->handleResult (object, result);
+}
+
+void QSnapdGetSnapRequest::runAsync ()
+{
+    Q_D(QSnapdGetSnapRequest);
+    snapd_client_get_snap_async (SNAPD_CLIENT (getClient ()), d->name.isNull () ? NULL : d->name.toStdString ().c_str (), G_CANCELLABLE (getCancellable ()), get_snap_ready_cb, (gpointer) this);
+}
+
+QSnapdSnap *QSnapdGetSnapRequest::snap () const
+{
+    Q_D(const QSnapdGetSnapRequest);
+    return new QSnapdSnap (d->snap);
+}
+
 static SnapdGetAppsFlags convertGetAppsFlags (int flags)
 {
     int result = SNAPD_GET_APPS_FLAGS_NONE;
@@ -1161,21 +1326,6 @@ QSnapdAddAssertionsRequest::QSnapdAddAssertionsRequest (const QStringList& asser
     QSnapdRequest (snapd_client, parent),
     d_ptr (new QSnapdAddAssertionsRequestPrivate (assertions)) {}
 
-static gchar **
-string_list_to_strv (const QStringList& list)
-{
-    gchar **value;
-    int size, i;
-
-    size = list.size ();
-    value = (gchar **) malloc (sizeof (gchar *) * (size + 1));
-    for (i = 0; i < size; i++)
-        value[i] = g_strdup (list[i].toStdString ().c_str ());
-    value[size] = NULL;
-
-    return value;
-}
-
 void QSnapdAddAssertionsRequest::runSync ()
 {
     Q_D(QSnapdAddAssertionsRequest);
@@ -1372,6 +1522,8 @@ static SnapdFindFlags convertFindFlags (int flags)
         result |= SNAPD_FIND_FLAGS_MATCH_NAME;
     if ((flags & QSnapdClient::FindFlag::SelectPrivate) != 0)
         result |= SNAPD_FIND_FLAGS_SELECT_PRIVATE;
+    if ((flags & QSnapdClient::FindFlag::ScopeWide) != 0)
+        result |= SNAPD_FIND_FLAGS_SCOPE_WIDE;
 
     return (SnapdFindFlags) result;
 }
