@@ -147,6 +147,9 @@ void QSnapdRequest::finish (void *error)
             case SNAPD_ERROR_NOT_IN_STORE:
                 d->error = QSnapdRequest::QSnapdError::NotInStore;
                 break;
+            case SNAPD_ERROR_AUTH_CANCELLED:
+                d->error = QSnapdRequest::QSnapdError::AuthCancelled;
+                break;
             default:
                 /* This indicates we should add a new entry here... */
                 d->error = QSnapdRequest::QSnapdError::UnknownError;
