@@ -67,6 +67,15 @@ QSnapdChannel *QSnapdSnap::matchChannel (const QString& name) const
     return new QSnapdChannel (channel);
 }
 
+QStringList QSnapdSnap::commonIds () const
+{
+    gchar **common_ids = snapd_snap_get_common_ids (SNAPD_SNAP (wrapped_object));
+    QStringList result;
+    for (int i = 0; common_ids[i] != NULL; i++)
+        result.append (common_ids[i]);
+    return result;
+}
+
 QSnapdEnums::SnapConfinement QSnapdSnap::confinement () const
 {
     switch (snapd_snap_get_confinement (SNAPD_SNAP (wrapped_object)))
@@ -95,7 +104,9 @@ QString QSnapdSnap::description () const
 
 QString QSnapdSnap::developer () const
 {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     return snapd_snap_get_developer (SNAPD_SNAP (wrapped_object));
+G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 bool QSnapdSnap::devmode () const
@@ -181,6 +192,35 @@ bool QSnapdSnap::isPrivate () const
     return snapd_snap_get_private (SNAPD_SNAP (wrapped_object));
 }
 
+QString QSnapdSnap::publisherDisplayName () const
+{
+    return snapd_snap_get_publisher_display_name (SNAPD_SNAP (wrapped_object));
+}
+
+QString QSnapdSnap::publisherId () const
+{
+    return snapd_snap_get_publisher_id (SNAPD_SNAP (wrapped_object));
+}
+
+QString QSnapdSnap::publisherUsername () const
+{
+    return snapd_snap_get_publisher_username (SNAPD_SNAP (wrapped_object));
+}
+
+QSnapdEnums::PublisherValidation QSnapdSnap::publisherValidation () const
+{
+    switch (snapd_snap_get_publisher_validation (SNAPD_SNAP (wrapped_object)))
+    {
+    case SNAPD_PUBLISHER_VALIDATION_UNPROVEN:
+        return QSnapdEnums::PublisherValidationUnproven;
+    case SNAPD_PUBLISHER_VALIDATION_VERIFIED:
+        return QSnapdEnums::PublisherValidationVerified;
+    case SNAPD_PUBLISHER_VALIDATION_UNKNOWN:
+    default:
+        return QSnapdEnums::PublisherValidationUnknown;
+    }
+}
+
 QString QSnapdSnap::revision () const
 {
     return snapd_snap_get_revision (SNAPD_SNAP (wrapped_object));
