@@ -45,14 +45,24 @@ const gchar    *mock_snapd_get_socket_path        (MockSnapd     *snapd);
 void            mock_snapd_set_close_on_request   (MockSnapd     *snapd,
                                                    gboolean       close_on_request);
 
+void            mock_snapd_set_decline_auth       (MockSnapd     *snapd,
+                                                   gboolean       decline_auth);
+
 gboolean        mock_snapd_start                  (MockSnapd     *snapd,
                                                    GError       **error);
 
 void            mock_snapd_stop                   (MockSnapd     *snapd);
 
+void            mock_snapd_set_build_id           (MockSnapd     *snapd,
+                                                   const gchar   *build_id);
+
 void            mock_snapd_set_confinement        (MockSnapd     *snapd,
                                                    const gchar   *confinement);
 
+void            mock_snapd_add_sandbox_feature    (MockSnapd     *snapd,
+                                                   const gchar   *backend,
+                                                   const gchar   *feature);
+
 void            mock_snapd_set_store              (MockSnapd     *snapd,
                                                    const gchar   *name);
 
@@ -62,6 +72,21 @@ void            mock_snapd_set_managed            (MockSnapd     *snapd,
 void            mock_snapd_set_on_classic         (MockSnapd     *snapd,
                                                    gboolean       on_classic);
 
+void            mock_snapd_set_refresh_hold       (MockSnapd     *snapd,
+                                                   const gchar   *refresh_hold);
+
+void            mock_snapd_set_refresh_last       (MockSnapd     *snapd,
+                                                   const gchar   *refresh_last);
+
+void            mock_snapd_set_refresh_next       (MockSnapd     *snapd,
+                                                   const gchar   *refresh_next);
+
+void            mock_snapd_set_refresh_schedule   (MockSnapd     *snapd,
+                                                   const gchar   *schedule);
+
+void            mock_snapd_set_refresh_timer      (MockSnapd     *snapd,
+                                                   const gchar   *timer);
+
 void            mock_snapd_set_suggested_currency (MockSnapd     *snapd,
                                                    const gchar   *currency);
 
@@ -159,6 +184,9 @@ void            mock_app_set_active               (MockApp       *app,
 void            mock_app_set_enabled              (MockApp       *app,
                                                    gboolean       enabled);
 
+void            mock_app_set_common_id            (MockApp       *app,
+                                                   const gchar   *id);
+
 void            mock_app_set_daemon               (MockApp       *app,
                                                    const gchar   *daemon);
 
@@ -183,6 +211,9 @@ void            mock_snap_set_channel             (MockSnap      *snap,
 
 const gchar    *mock_snap_get_channel             (MockSnap      *snap);
 
+void            mock_snap_add_common_id           (MockSnap      *snap,
+                                                   const gchar   *id);
+
 MockTrack      *mock_snap_add_track               (MockSnap      *snap,
                                                    const gchar   *name);
 
@@ -223,9 +254,6 @@ const gchar    *mock_snap_get_data                (MockSnap      *snap);
 void            mock_snap_set_description         (MockSnap      *snap,
                                                    const gchar   *description);
 
-void            mock_snap_set_developer           (MockSnap      *snap,
-                                                   const gchar   *developer);
-
 void            mock_snap_set_devmode             (MockSnap      *snap,
                                                    gboolean       devmode);
 
@@ -274,6 +302,18 @@ MockPrice      *mock_snap_add_price               (MockSnap      *snap,
                                                    gdouble        amount,
                                                    const gchar   *currency);
 
+void            mock_snap_set_publisher_display_name (MockSnap *snap,
+                                                      const gchar *display_name);
+
+void            mock_snap_set_publisher_id        (MockSnap *snap,
+                                                   const gchar *id);
+
+void            mock_snap_set_publisher_username  (MockSnap *snap,
+                                                   const gchar *username);
+
+void            mock_snap_set_publisher_validation (MockSnap *snap,
+                                                    const gchar *validation);
+
 void            mock_snap_set_restart_required    (MockSnap      *snap,
                                                    gboolean       restart_required);
 
@@ -282,6 +322,9 @@ void            mock_snap_set_revision            (MockSnap      *snap,
 
 const gchar    *mock_snap_get_revision            (MockSnap      *snap);
 
+void            mock_snap_set_scope_is_wide       (MockSnap      *snap,
+                                                   gboolean       scope_is_wide);
+
 MockScreenshot *mock_snap_add_screenshot          (MockSnap      *snap,
                                                    const gchar   *url,
                                                    int            width,
